Ajax — CKEditor Sample

# CKEditor Samples » Create and Destroy Editor Instances for Ajax Applications

This sample shows how to create and destroy CKEditor instances on the fly. After the removal of CKEditor the content created inside the editing area will be displayed in a `<div>` element.

For details of how to create this setup check the source code of this sample page for JavaScript code responsible for the creation and destruction of a CKEditor instance.

Click the buttons to create and remove a CKEditor instance.

Edited Contents: